@@ -1,4 +1,4 @@
-/** Copyright John Reid 2011, 2012
+/** Copyright John Reid 2011, 2012, 2013
  *
  * \file
  * \brief Basic definitions and includes for STEME algorithm.
@@ -191,6 +191,27 @@ extern const double log_95;
 extern const double log_05;
 
 
+
+/**
+ * Convert a likelihood ratio to a probability.
+ */
+template< typename FPT >
+FPT
+lr_to_prob( FPT lr ) {
+    return lr / ( lr + FPT( 1 ) );
+}
+
+
+/**
+ * Convert a likelihood ratio to a probability.
+ */
+template< typename FPT >
+FPT
+prob_to_lr( FPT p ) {
+    return p / ( FPT( 1 ) - p );
+}
+
+
 /**
  * Do two W-mers overlap?
  */
